@@ -10,6 +10,10 @@ import pexpect, time
 # echo "alias config='/usr/bin/git --git-dir=$HOME/.cfg/ --work-tree=$HOME'" >> $HOME/.bashrc
 
 def runccore(*args):
+    click.echo(click.style('.g.  ', fg='cyan'),nl=False)
+    click.echo(click.style(" ".join(args), fg='bright_white'))
+    click.echo(click.style('.g.  ', fg='cyan'),nl=True)
+
     p = pexpect.spawn(" ".join(args))
     lines = p.readlines()
     for l in lines:
@@ -21,7 +25,7 @@ def runccore(*args):
         time.sleep(1)
         timeout-=1
     p.close()
-    click.echo(click.style('', fg='cyan'),nl=True)
+    click.echo(click.style('...', fg='cyan'),nl=True)
 
     return p.exitstatus
 
@@ -68,10 +72,15 @@ def clone( repo ):
     with open( "%s/.gitignore" % os.environ["HOME"], "a" ) as file: # Use file to refer to the file object
         file.write( "%s/.dotstrap\n" % os.environ["HOME"] )
 
-    runccore("git", "clone", "--bare", repo, "%s/.dotstrap" % os.environ["HOME"])
-
-    if run( "checkout" ) != 0:
-        echo(click.style('could not checkout - did you specify a valid repo? or maybe some files were in the way?', fg="red"))
+    clone = runccore("git", "clone", "--bare", repo, "%s/.dotstrap" % os.environ["HOME"])
+    checkout = run( "checkout" )
+    if clone != 0 or checkout != 0:
+        echo(click.style('could not checkout repository :(', fg="red"))
+        echo(click.style('things to check:', fg="white"))
+        echo(click.style(' - did you specfy a valid repo?', fg="white"))
+        echo(click.style(' - are you authenticated for the repo?', fg="white"))
+        echo(click.style(' - maybe you have some files in the way for a checkout?', fg="white"))
+        echo(click.style('     try moving them away or deleting them.', fg="white"))
         return
 
     run( "config", "--local", "status.showUntrackedFiles", "no" )
@@ -113,9 +122,9 @@ def sync():
     """Git sync with remote origin"""
     run( "pull", "--rebase", "origin", "master" )
     if run( "push", "origin", "master" ) != 0:
-        echo(click.style('could not push to remote master - repos out of sync?', fg="red"))
+        echo(click.style('could not push to remote master - repo out of sync?', fg="red"))
         return
-    echo(click.style('repos synced', fg="green"))
+    echo(click.style('repo synced', fg="green"))
 
 @click.command()
 @click.argument('args', nargs=-1)
